thorn.tasks — Thorn 1.3.0 documentation

# thorn.tasks

- thorn.tasks

## thorn.tasks

Tasks used by the Celery dispatcher.

(task)`thorn.tasks.` `send_event`

  Task called by process dispatching the event.

  This will use the WorkerDispatcher to dispatch the individual HTTP requests in batches (`dispatch_requests -> dispatch_request`).

(task)`thorn.tasks.` `dispatch_requests`

  Process a batch of HTTP requests.

(task)`thorn.tasks.` `dispatch_request`

  Process a single HTTP request.